// LICENSE : MIT
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFixerFormatterList = exports.createFormatter = void 0;
const module_interop_1 = require("@textlint/module-interop");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const tryResolve = require("try-resolve");
const isFile = require("is-file");
const debug = require("debug")("textlint:textfix-formatter");
function createFormatter(formatterConfig) {
    const formatterName = formatterConfig.formatterName;
    debug(`formatterName: ${formatterName}`);
    let formatter;
    let formatterPath;
    if (fs_1.default.existsSync(formatterName)) {
        formatterPath = formatterName;
    }
    else if (fs_1.default.existsSync(path_1.default.resolve(process.cwd(), formatterName))) {
        formatterPath = path_1.default.resolve(process.cwd(), formatterName);
    }
    else {
        if (isFile(`${path_1.default.join(__dirname, "formatters/", formatterName)}.js`)) {
            formatterPath = `${path_1.default.join(__dirname, "formatters/", formatterName)}.js`;
        }
        else if (isFile(`${path_1.default.join(__dirname, "formatters/", formatterName)}.ts`)) {
            formatterPath = `${path_1.default.join(__dirname, "formatters/", formatterName)}.ts`;
        }
        else {
            const pkgPath = tryResolve(`textlint-formatter-${formatterName}`) || tryResolve(formatterName);
            if (pkgPath) {
                formatterPath = pkgPath;
            }
        }
    }
    try {
        formatter = module_interop_1.moduleInterop(require(formatterPath));
    }
    catch (ex) {
        throw new Error(`Could not find formatter ${formatterName}
See https://github.com/textlint/textlint/issues/148
${ex}`);
    }
    debug(`use formatter: ${formatterPath}`);
    return function (results) {
        return formatter(results, formatterConfig);
    };
}
exports.createFormatter = createFormatter;
function getFixerFormatterList() {
    return fs_1.default
        .readdirSync(path_1.default.join(__dirname, "formatters"))
        .filter((file) => {
        const fileName = path_1.default.extname(file);
        return fileName === ".js" || fileName === ".ts";
    })
        .map((file) => {
        return { name: path_1.default.basename(file, path_1.default.extname(file)) };
    });
}
exports.getFixerFormatterList = getFixerFormatterList;
//# sourceMappingURL=index.js.map