// LICENSE : MIT
"use strict";
import { moduleInterop } from "@textlint/module-interop";
import fs from "fs";
import path from "path";
const tryResolve = require("try-resolve");
const isFile = require("is-file");
const debug = require("debug")("textlint:textfix-formatter");
export function createFormatter(formatterConfig) {
    const formatterName = formatterConfig.formatterName;
    debug(`formatterName: ${formatterName}`);
    let formatter;
    let formatterPath;
    if (fs.existsSync(formatterName)) {
        formatterPath = formatterName;
    }
    else if (fs.existsSync(path.resolve(process.cwd(), formatterName))) {
        formatterPath = path.resolve(process.cwd(), formatterName);
    }
    else {
        if (isFile(`${path.join(__dirname, "formatters/", formatterName)}.js`)) {
            formatterPath = `${path.join(__dirname, "formatters/", formatterName)}.js`;
        }
        else if (isFile(`${path.join(__dirname, "formatters/", formatterName)}.ts`)) {
            formatterPath = `${path.join(__dirname, "formatters/", formatterName)}.ts`;
        }
        else {
            const pkgPath = tryResolve(`textlint-formatter-${formatterName}`) || tryResolve(formatterName);
            if (pkgPath) {
                formatterPath = pkgPath;
            }
        }
    }
    try {
        formatter = moduleInterop(require(formatterPath));
    }
    catch (ex) {
        throw new Error(`Could not find formatter ${formatterName}
See https://github.com/textlint/textlint/issues/148
${ex}`);
    }
    debug(`use formatter: ${formatterPath}`);
    return function (results) {
        return formatter(results, formatterConfig);
    };
}
export function getFixerFormatterList() {
    return fs
        .readdirSync(path.join(__dirname, "formatters"))
        .filter((file) => {
        const fileName = path.extname(file);
        return fileName === ".js" || fileName === ".ts";
    })
        .map((file) => {
        return { name: path.basename(file, path.extname(file)) };
    });
}
//# sourceMappingURL=index.js.map